@@ -223,3 +223,11 @@ def simple_search(save_dir: str,
     h5 = H5(save_dir, l1_size=l1_size)
     return h5.search(vids, max_parallel=max_parallel)
 
+
+
+def simple_add(save_dir: str,
+               data_pairs: list,
+               l1_size: int = 100,
+               l2_size: int = 2000):
+    h5 = H5(save_dir, l1_size=l1_size)
+    h5.multiple_file_add(data_pairs)
